@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1500';
+our $VERSION = '0.1600';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -28,6 +28,7 @@ sub _input_from_string
 
     if($str !~ m{\AFoundations: H-($rank_re) C-($rank_re) D-($rank_re) S-($rank_re) *\z}ms)
     {
+        die "str=<$str>";
         Games::Solitaire::Verify::Exception::Parse::State::Foundations->throw(
             error => "Wrong Foundations",
         );
@@ -132,8 +133,6 @@ sub to_string
 
     return   "Foundations:"
            . join("", @{$self->_foundations_strings()})
-           . " " # We need the trailing space for compatibility with
-                 # Freecell Solver.
            ;
 }
 
@@ -179,7 +178,7 @@ foundations (or home-cells) in a Solitaire game.
 
 =head1 VERSION
 
-version 0.1500
+version 0.1600
 
 =head1 SYNOPSIS
 
